

/* AIAA OC Rocketry
   This sketch uses the NTCCLE100E3103JB0 Thermistor to measure temperature.  All of the calculations are done in the ntc10k library
   The circuitry is simple (Note that the Thermistor is at the "top" of the divider):
   
                                          ---------------          ---------------
                                +5VDC ---| NTC Thermistor|--------|  10K Ohm Res  |----- GND
                                          ---------------     |    ----------------
                                                 NTC          |           R1
                                                              |
                                                        Arduino A/D (4)

   The Thermistor and 10K ohm resistor form a voltage divider.  As the temperature goes down, the Thermistor resistance goes up, wo the voltage read by the Arduino
   goes down [A/D voltage = R1 / (R1 + NTC) * 5VDC]
   The code in the NTC10k library (from http://playground.arduino.cc/ComponentLib/Thermistor2):
        #include <math.h>
        static float pad = 10000;  // this is the value of the resistor in the circuit
        float ntc10kTemp (int RawADC) {
        long Resistance;  
        float Temp;  // Dual-Purpose variable to save space.

        Resistance=((1024 * pad / RawADC) - pad);
        Temp = log(Resistance); // Saving the Log(resistance) so not to calculate  it 4 times later
        Temp = 1 / (0.001129148 + (0.000234125 * Temp) + (0.0000000876741 * Temp * Temp * Temp));
        Temp = Temp - 273.15;  // Convert Kelvin to Celsius
        return (Temp);
    You will need to measure the actual value of your resistor and insert that value for pad in the library (ntc10k.cpp file) to calibrate
*/      
    
#include <ntc10k.h>

#define ADCPort 4   // this is the Analog to Digital Converter channel that you have wired to
#define LoopTime 250 // allows you to adjust the time between sending data (in milliseconds - lower number is faster)

void setup()
{
  Serial.begin(9600);
}

void loop()
{
  Serial.println(ntc10kTemp(analogRead(ADCPort)));
  delay(LoopTime);
}

